/*
 * base91.h
 * Greg Cook, 21/Aug/2020
 *
 * Base91: encodes and decodes files in base91 ASCII
 *
 * Common definitions
 */

#ifndef BASE91_H
#  define BASE91_H

#  include <stdio.h>
#  include <stdlib.h>
#  include <string.h>
#  include "getopt.h"

#  ifdef MODES
#    include <sys/types.h>      /* because stat(2) says so */
#    include <sys/stat.h>       /* for stat(), chmod(), umask() */
#    ifdef _WIN32
#      include <io.h>           /* where umask() lives in MinGW */
#    endif
#  endif

#  ifdef  INLINE
#    undef  INLINE
#    define INLINE inline
#  else
#    define INLINE
#  endif

#  define VERSION "3.12"

#  define U_POS        1
#  define U_CRC        2
#  define U_CRCD       4
#  define U_INTCHK     8
#  define U_RLE       16
#  define U_STDOUT    32
#  define U_DECODE    64
#  define U_OFILE    128
#  define U_TYPEA    256
#  define U_PAD      512
#  define U_SUMMAR  1024

#  define LNSZ       512

#  define BUFSZ    32768

#  define PADCH ' '

/* cli.c */
extern int main(int argc, char *argv[]);
extern void error(const char *msg);
extern void usage(void);

extern const char *myname, *src, *dest;

/* decode.c */
extern void decode(FILE *input, const char *ofile, int flags);

/* encode.c */
extern void encode(FILE *out, const char *fname, const char *ofile,
  int flags, size_t blocsz, int cols);
extern void endenc(void);

/*sfread.c */
#  ifdef _WIN32
#    define SF_BADSZ 28672
#    define SF_CHUNK 16384
#    define FREAD(ptr, size, nelem, stream) sfread(ptr, size, nelem, stream)
extern size_t sfread(void *ptr, size_t size, size_t nelem, FILE *stream);
#  else  /* _WIN32 */
#    define FREAD(ptr, size, nelem, stream) fread(ptr, size, nelem, stream)
#  endif /* _WIN32 */

/* tables.c */
extern const unsigned short counts[];
extern const unsigned long crc32c[];
extern const unsigned long crc32d[];

#endif /* BASE91_H */

/* End of base91.h */
/* vim:tw=72:nocin:ai:et:
*/
