/*
 * sfread.c
 * Greg Cook, 5/Oct/2019
 *
 * Base91: encodes and decodes files in base91 ASCII
 *
 * Safe fread() for reading stdin in MinGW32
 */

#include "base91.h"

#ifdef _WIN32
size_t sfread(void *ptr, size_t size, size_t nelem, FILE *stream) {
  size_t target = size * nelem, got = SF_CHUNK, total = 0;
  char *cptr = ptr;

  if(stream == stdin && target >= (size_t) SF_BADSZ) {
    while(got == SF_CHUNK && target >= SF_CHUNK) {
      got = fread(cptr, 1, SF_CHUNK, stream);
      total += got;
      cptr += got;
      target -= got;
    }
    if(got == SF_CHUNK && target) {
      got = fread(cptr, 1, target, stream);
      total += got;
    }
    return(total / size);
  } else{
    return(fread(ptr, size, nelem, stream));
  }
}
#endif /* _WIN32 */

/* End of sfread.c */
/* vim:tw=72:nocin:ai:et:
*/
